<?php
/**
 * WG Piccolo Pro functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package sheila
 */

if ( ! function_exists( 'sheila_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function sheila_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on sheila, use a find and replace
	 * to change 'sheila' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'sheila', get_template_directory() . '/languages' );

		/*
	 * Set woocommerce support  
	 * 
	 */
	add_theme_support( 'woocommerce' );
	
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'post-thumb', 770,300, true );
	add_image_size( 'sheila_port_thumb', 1200,800, true );
	add_image_size( 'sheila_team_thumb', 870,984, true );
	add_image_size( 'sheila_test_thumb', 200,200, true );
	add_image_size( 'sheila_latest_blot_thumb', 850,588, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Header Menu', 'sheila' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_theme_support( 'post-formats', array(
		'audio',
		'video',
		'quote',
	) );
	
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'sheila_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
add_editor_style( array( 'assets/css/editor-style.css', sheila_fonts_url() ) );
}
endif;
add_action( 'after_setup_theme', 'sheila_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sheila_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'sheila_content_width', 640 );
}
add_action( 'after_setup_theme', 'sheila_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sheila_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'sheila' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'sheila' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );	
	
	register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'sheila' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'sheila' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'sheila_widgets_init' );


/**
 * register google fonts
 */
function sheila_fonts_url() {
	$fonts_url = '';
	
	/* Translators: If there are characters in your language that are not
	* supported by Source Sans Pro, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$source_sans_pro = _x( 'on', 'Source Sans Pro font: on or off', 'sheila' );

	/* Translators: If there are characters in your language that are not
	* supported by Merriweather, translate this to 'off'. Do not translate
	* into your own language.
	*/
	
	$merriweather = _x( 'on', 'Merriweather: on or off', 'sheila' );	
	
	/* Translators: If there are characters in your language that are not
	* supported by Lato, translate this to 'off'. Do not translate
	* into your own language.
	*/
	
	$montserrat = _x( 'on', 'Montserrat font: on or off', 'sheila' );
	
	if ( 'off' !== $source_sans_pro || 'off' !== $merriweather || 'off' !== $montserrat ) {
	$font_families = array();
	 
	if ( 'off' !== $source_sans_pro ) {
	$font_families[] = 'Source Sans Pro:400,300,600,700';
	}
	 
	if ( 'off' !== $merriweather ) {
	$font_families[] = 'Merriweather:400,700,900,300';
	}	
	
	if ( 'off' !== $montserrat ) {
	$font_families[] = 'Montserrat:400,700';
	}
	 
	$query_args = array(
	'family' => urlencode( implode( '|', $font_families ) ),
	'subset' => urlencode( 'latin,latin-ext' ),
	);

	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}
	 
	return esc_url_raw( $fonts_url );	
}


/**
 * Enqueue scripts and styles.
 */
function sheila_scripts() {
	

	wp_enqueue_style( 'google-fonts', sheila_fonts_url(), array(), null );
	wp_enqueue_style('bootstrap', get_template_directory_uri() .  '/assets/bootstrap/css/bootstrap.min.css');
	wp_enqueue_style('font-awosome', get_template_directory_uri() .  '/assets/fonts/font-awesome.min.css');
	wp_enqueue_style('owl.carousel', get_template_directory_uri() .  '/assets/owlcarousel/css/owl.carousel.css');
	wp_enqueue_style('owl.theme', get_template_directory_uri() .  '/assets/owlcarousel/css/owl.theme.css');
	wp_enqueue_style('animate', get_template_directory_uri() . '/assets/css/animate.css');
	wp_enqueue_style('style', get_template_directory_uri() . '/assets/css/style.css');

	wp_enqueue_style( 'sheila-style', get_stylesheet_uri() );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/bootstrap/js/bootstrap.min.js', array('jquery'), '20120206', true );
	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/assets/js/modernizr.custom.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'jquery.stellar.min', get_template_directory_uri() . '/assets/js/jquery.stellar.min.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'jquery.nav', get_template_directory_uri() . '/js/jquery.nav.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'jquery.inview.min', get_template_directory_uri() . '/assets/js/jquery.inview.min.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'owl.carousel.min', get_template_directory_uri() . '/assets/owlcarousel/js/owl.carousel.min.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'jquery.mixitup', get_template_directory_uri() . '/assets/js/jquery.mixitup.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'scrolltopcontrol', get_template_directory_uri() . '/assets/js/scrolltopcontrol.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'jquery.appear', get_template_directory_uri() . '/assets/js/jquery.appear.js', array('jquery'), '20130115', true );
	wp_enqueue_script( 'wow.min', get_template_directory_uri() . '/assets/js/wow.min.js', array('jquery'), '20130115', true );
	
	wp_enqueue_script( 'scripts', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), '201301120', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sheila_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

require get_template_directory() . '/inc/navwalker.php';
require get_template_directory() . '/inc/custom_functions.php';
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/required-plugin.php';
require get_template_directory() . '/inc/demo_install.php';

/*---------------------------------------------
 Initialising KingComposer shortcode editor
----------------------------------------------*/ 
if (class_exists('KingComposer')) {
 function sheila_requireKcExtend(){
  include_once( get_template_directory().'/kc_extend/extend_kc.php');  
 }
 add_action('init', 'sheila_requireKcExtend',2);
}

function sheila_main_menu() {
		wp_nav_menu( array(
		'theme_location'    => 'primary',
		'depth'             => 5,
		'container'         => false,
		'menu_class'        => 'nav navbar-nav navbar-right',
		'fallback_cb'       => 'sheila_navwalker::fallback',
		
		)
	); 	
}

function sheila_wp_kses($val){
	return wp_kses($val, array(
	
	'p' => array(
		'class' =>array()
	),
	'span' => array(),
	'small' => array(),
	'div' => array(),
	'strong' => array(),
	'b' => array(),
	'br' => array(),
	'h1' => array(),
	'i' => array(
		'class' =>array()
	),	
	'ul' => array(
		'class' =>array()
	),	
	'ul' => array(
		'id' =>array()
	),	
	'li' => array(
		'class' =>array()
	),	
	'li' => array(
		'id' =>array()
	),
	'h2' => array(),
	'h3' => array(),
	'h4' => array(),
	'h5' => array(),
	'h6' => array(),
	'a'=> array('href' => array(),'target' => array()),
	'iframe'=> array('src' => array(),'height' => array(),'width' => array()),
	
	), '');
}

// modify search widget
function sheila_my_search_form( $form ) {
	$form = '
		<div class="search_form">
			<form role="search" method="get" id="searchform" class="searchform" action="' . esc_url(home_url( '/' )) . '" >
			<input type="text" value="' . esc_attr(get_search_query()) . '" name="s" id="s" class="form-control" placeholder="' . esc_attr__('Enter Keyword Here &amp; Search...' , 'sheila') .'">
			<button type="submit"><i class="fa fa-search"></i></button>
			<input type="hidden" id="post_type" name="post_type" value="post">
			</form>
		</div>
		
        ';
	return $form;
}
add_filter( 'get_search_form', 'sheila_my_search_form' );

// comment list modify

function sheila_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>

<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
	<div class="single_comment">
		<div class="media">
			<div class="comment_avatar">
				<?php echo get_avatar( $comment, 70 ); ?>
			</div>

			<div class="commnet-body text-left comment_single">
				
				<h5 class="media-heading comm-title"><?php comment_author_link() ?></h5>
				<span class="com-date"><?php echo esc_html(get_comment_date('F j, Y')); ?> <?php echo esc_html(get_comment_date('g:i')); ?></span>
				<?php if ($comment->comment_approved == '0') : ?>
				<p><em><?php esc_html_e('Your comment is awaiting moderation.','sheila'); ?></em></p>
				<?php endif; ?>
				 <?php comment_text(); ?>						
				<div class="creply_link"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></div>				 
			</div>
		</div>
	</div>				
</li>


<?php }

// comment box title change
add_filter( 'comment_form_defaults', 'sheila_remove_comment_form_allowed_tags' );
function sheila_remove_comment_form_allowed_tags( $defaults ) {

	$defaults['comment_notes_after'] = '';
	$defaults['comment_notes_before'] = '';
	return $defaults;

}

function sheila_comment_reform ($arg) {

$arg['title_reply'] = esc_html__('Write comment','sheila');
$arg['comment_field'] = '<div class="row"><div class="form-group has-feedback col-md-12"><textarea id="comment" class="comment_field" name="comment" cols="77" rows="3" placeholder="'. esc_html__("Write your Comment", "sheila").'" aria-required="true"></textarea></div></div>';


return $arg;

}
add_filter('comment_form_defaults','sheila_comment_reform');

// comment form modify

function sheila_modify_comment_form_fields($fields){
	$commenter = wp_get_current_commenter();
	$req	   = get_option( 'require_name_email' );

	$fields['author'] = '<div class="row"><div class="form-group has-feedback col-md-4"><input type="text" name="author" id="author" value="'. esc_attr( $commenter['comment_author'] ) .'" placeholder="'. esc_attr__("Your Name *", "sheila").'" size="22" tabindex="1"'. ( $req ? 'aria-required="true"' : '' ).' class="input-name form-control" /></div>';

	$fields['email'] = '<div class="form-group has-feedback col-md-4"><input type="text" name="email" id="email" value="'. esc_attr( $commenter['comment_author_email'] ) .'" placeholder="'.esc_attr__("Your Email *", "sheila").'" size="22" tabindex="2"'. ( $req ? 'aria-required="true"' : '' ).' class="input-email form-control"  /></div>';
	
	$fields['url'] = '<div class="form-group has-feedback col-md-4"><input type="text" name="url" id="url" value="'. esc_attr( $commenter['comment_author_url'] ) .'" placeholder="'. esc_attr__("Website", "sheila").'" size="22" tabindex="2"'. ( $req ? 'aria-required="false"' : '' ).' class="input-url form-control"  /></div></div>';

	return $fields;
}
add_filter('comment_form_default_fields','sheila_modify_comment_form_fields');
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327905&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        